#![no_std]
#![no_main]

use embedded_graphics::{mono_font::{ascii::FONT_6X10, MonoTextStyleBuilder}, pixelcolor::BinaryColor, prelude::Point, text::{Baseline, Text}, Drawable};
use esp_backtrace as _;
use esp_hal::{delay::Delay, i2c::master::{Config, I2c}, time::Duration, xtensa_lx_rt::entry};
use ssd1306::{mode::DisplayConfig, prelude::DisplayRotation, size::DisplaySize128x64, I2CDisplayInterface, Ssd1306};

        #[entry]
        fn main() -> ! {
            let peripherals = esp_hal::init(esp_hal::Config::default());
            let delay = Delay::new();

            // let system = SystemControl::new(peripherals.SYSTEM);
            // let delay = Delay::new();

            esp_println::logger::init_logger_from_env();

            // Create a new peripheral object with the described wiring
            // and standard I2C clock speed
            let i2c = I2c::new(
                peripherals.I2C0,
                Config::default()
            ).unwrap().with_scl(peripherals.GPIO22).with_sda(peripherals.GPIO21);

            let interface = I2CDisplayInterface::new(i2c);
            let mut display = Ssd1306::new(interface, DisplaySize128x64, DisplayRotation::Rotate0)
                .into_buffered_graphics_mode();
            display.init().unwrap();

            let text_style = MonoTextStyleBuilder::new()
                .font(&FONT_6X10)
                .text_color(BinaryColor::On)
                .build();

            Text::with_baseline("Hello world!", Point::zero(), text_style, Baseline::Top)
                .draw(&mut display)
                .unwrap();

            Text::with_baseline("Hello Rust!", Point::new(0, 16), text_style, Baseline::Top)
                .draw(&mut display)
                .unwrap();

            display.flush().unwrap();
            loop {
                log::info!("Hello world!");
                delay.delay(Duration::millis(500));
            }
        }
